package org.apache.bcel.classfile;

import java.io.DataOutputStream;
import java.io.IOException;
import java.io.DataInput;

public final class SourceFile extends Attribute
{
    private int sourceFileIndex;
    
    SourceFile(final int nameIndex, final int length, final DataInput input, final ConstantPool constantPool) throws IOException {
        this(nameIndex, length, input.readUnsignedShort(), constantPool);
    }
    
    public SourceFile(final int nameIndex, final int length, final int sourceFileIndex, final ConstantPool constantPool) {
        super((byte)0, nameIndex, length, constantPool);
        this.sourceFileIndex = sourceFileIndex;
    }
    
    public SourceFile(final SourceFile c) {
        this(c.getNameIndex(), c.getLength(), c.getSourceFileIndex(), c.getConstantPool());
    }
    
    @Override
    public void accept(final Visitor v) {
        v.visitSourceFile(this);
    }
    
    @Override
    public Attribute copy(final ConstantPool constantPool) {
        return (Attribute)this.clone();
    }
    
    @Override
    public void dump(final DataOutputStream file) throws IOException {
        super.dump(file);
        file.writeShort(this.sourceFileIndex);
    }
    
    public int getSourceFileIndex() {
        return this.sourceFileIndex;
    }
    
    public String getSourceFileName() {
        return super.getConstantPool().getConstantUtf8(this.sourceFileIndex).getBytes();
    }
    
    public void setSourceFileIndex(final int sourceFileIndex) {
        this.sourceFileIndex = sourceFileIndex;
    }
    
    @Override
    public String toString() {
        return "SourceFile: " + this.getSourceFileName();
    }
}
